@@ -129,15 +129,21 @@ NULL
 #' ## Model with DP on clients effects, but now INCLUDE session random effects
 #' ## in a multiple membership construction communicated with the N x S matrix, W.subj.aff.
 #' ## Returns object, res.mm, of class "dpgrowmm".
-#' shape.dp		= 3
-#' strength.mm		= 0.001
-#' res.mm			= dpgrowmm(y = datsim$y, subject = datsim$subject, trt = datsim$trt, time = datsim$time, n.random = datsim$n.random, 
-#'						n.fix_degree = 2, Omega = datsim$Omega, group = datsim$group, subj.aff = datsim$subj.aff,
-#'						W.subj.aff = datsim$W.subj.aff, n.iter = 10000, n.burn = 2000, n.thin = 10,
-#'						shape.dp = shape.dp, rate.dp = rate.dp, strength.mm = strength.mm, option = "mmcar")
-#' plot.results			= plot(res.mm) ## ggplot2 plot objects, including growth curves
-#' summary.results		= summary(res.mm) ## parameter credible intervals and fit statistics
-#' samples.posterior		= samples(res.mm) ## posterior sampled values
+#' shape.dp	= 3
+#' strength.mm	= 0.001
+#' res.mm	= dpgrowmm(y = datsim$y, subject = datsim$subject, 
+#'			trt = datsim$trt, time = datsim$time, 
+#'			n.random = datsim$n.random, 
+#'			n.fix_degree = 2, Omega = datsim$Omega, 
+#'			group = datsim$group, 
+#'			subj.aff = datsim$subj.aff,
+#'			W.subj.aff = datsim$W.subj.aff, 
+#'			n.iter = 10000, n.burn = 2000, n.thin = 10,
+#'			shape.dp = shape.dp, rate.dp = rate.dp, 
+#'			strength.mm = strength.mm, option = "mmcar")
+#' plot.results		= plot(res.mm) ## ggplot2 plot objects,
+#' summary.results	= summary(res.mm) ## credible intervals and fit statistics
+#' samples.posterior	= samples(res.mm) ## posterior sampled values
 #' }
 #' @aliases dpgrowmm
 #' @aliases dpgrowmm.default
@@ -288,6 +294,8 @@ dpgrowmm.default		<- function(y = NULL, subject, trt = NULL, time = NULL, n.rand
 	{
 		stop("Data must include random effects; either input in 'formula' and 'data' or generated by 'time' and 'n.random'.")
 	}
+
+	if( !is.null(data) ){ warning("If you want to include supplemental or nuisance predictors in the 'data' input, must also include the 'formula' input to tell the model their structure.")}
   }
 
   if( is.null(data) & is.null(time) )
@@ -427,7 +435,8 @@ dpgrowmm.default		<- function(y = NULL, subject, trt = NULL, time = NULL, n.rand
   	W.subj[subj.aff,]			= W.subj.aff
   	## W.subj[subj.ntrt,]		= 0
   }else{ ## all subjects should be linked to multiple membership affects
-	W.subj				= W.subj.aff
+	W.subj				= W.subj.aff  ## may be input by user as a data.frame object
+	W.subj				= as.matrix(W.subj) ## need W.subj to be a matrix object in growthCurves to differentiate from dpgrowmult object, where it is a list
   } ## end conditional statement on whether exists subj.aff subset of subject
 
   W.case			= W.subj[subject,]
@@ -473,6 +482,7 @@ dpgrowmm.default		<- function(y = NULL, subject, trt = NULL, time = NULL, n.rand
 		stopifnot( ncol(res$U) == (Nmv*Nsession) )
 	}else{ ## option == "mmcar"
 		print("Your chosen option = mmcar for multivariate MM effects")
+		omega.plus	= rowSums(Omega)
 		corsess		= 0 ## correlations in prior scale matrix for wishart prior on precision matrix for effects order
 		typemm		= 1 ## "mmcar"
 		res 		= mmCmvplusDpPost(y, X, Z, H, W.case, W.subj.aff, Omega, omega.plus, group, subject, n.iter, n.burn, n.thin, strength.mm, corsess, shape.dp, rate.dp, typemm)
